//set up globals for each function, so the data can be refiltered and reused after editing
rp_archive_fp_resetValues();
default_sort = floorplans_data['selected_sort'];
var google_tag_events = 0;

document.addEventListener('DOMContentLoaded', function(){ 
    //set up the element events on the page on the page
    document.getElementById("floorplan_sort").onchange = function() {rp_archive_fp_makeAllCards(floorplans)};
    document.getElementById("reset_button").onclick = function() {rp_archive_fp_resetFilters()};
    document.getElementById("apply_filters_button").onclick = function() {rp_archive_fp_applyFilters()};

    //construct the page and capture the slider element globally
    window.price_range_slider = rp_archive_fp_constructPriceSlider();
    rp_archive_fp_constructPage();

    //make the hide toggle html element work
    document.getElementById("rp-archive-fp-toggle-filters").onclick = function() {
        this.classList.toggle('rp-is-open');
        this.classList.toggle('rp-is-closed');
        document.getElementById("rp-archive-fp-sidebar").classList.toggle('rp-is-open');
        document.getElementById("rp-archive-fp-data").classList.toggle('rp-is-open');
        if(this.classList.contains('rp-is-open')){
            this.innerText = ' Hide Filters';
        } else {
            this.innerText = ' Show Filters';
        }
    };

    document.getElementById("rp-archive-fp-open-mobile-open-filters").onclick = function() {
        document.getElementById("rp-archive-fp-sidebar").classList.toggle('rp-is-mobile-open');
    };

}, false);

function rp_archive_fp_constructPage() {

    //set the parameter object with the new url
    params = new URLSearchParams(location.search);
    filters = [...params.entries()];

    //filter out the floorplans, then construct the new floorplan cards
    floorplans = all_floorplans_data['all_floorplans'];
    all_floorplans_bed_types = rp_archive_fp_getUniqueBedTypes(all_floorplans_data['all_floorplans']);
    floorplans = rp_archive_fp_filterFloorplans(floorplans);
    rp_archive_fp_makeAllCards(floorplans);
    rp_archive_fp_constructBedroomsFilter(all_floorplans_bed_types);

    //check the slider values
    price = params.get('selected_price_range');
    if (price) {
        price = price.split("-");
        price_range_slider.noUiSlider.updateOptions({
            start: [price[0], price[1]]
        });
    }
        
}

/**
* this function runs if the reset button is clicked
* has no params or returns
* just sets the url to default and resets the shown floorplans to all floorplans
*/
function rp_archive_fp_resetFilters() {
    //rewrite url
    history.replaceState(
        {},
        document.title,
        location.origin+location.pathname
    );

    //reset the values
    rp_archive_fp_resetValues();

    //reset the parameter object
    params = new URLSearchParams(location.search);
    filters = [...params.entries()];

    //make the price slider have base values
    price_range_slider.noUiSlider.updateOptions({
        start: [floorplans_data.rent_range.min, floorplans_data.rent_range.max]
    });

    //reset the selector
    document.getElementById('floorplans_available_filter').value = "";

    //remake all of the cards
    rp_archive_fp_makeAllCards(floorplans);
    //list all the bedroom types
    rp_archive_fp_constructBedroomsFilter(all_floorplans_bed_types);
}

/**
* this function runs if the apply button is clicked
* has no params or returns
* just sets the url to whatever was selected and filters the floorplans
**/
function rp_archive_fp_applyFilters() {

    //reset the values
    rp_archive_fp_resetValues();

    //get the selected values from the html elements
    paramStr = "";
    x = document.getElementsByName("selected_floorplans_beds");
    y = document.getElementById("floorplans_available_filter");
    z = document.getElementById("rp-archive-fp-price-range").innerText.split("\n");

    //for each floorplan selected, add it to the parameter stream
    for (var i = x.length - 1; i >= 0; i--) {
        if (x[i].checked == true) {
            paramStr += 'selected_floorplans_beds='+x[i].value+'&';
        }
    }

    //if a date selection has been made, add that to the parameter string
    if (y.options[y.selectedIndex].value != '') {
        paramStr += 'floorplans_available_by='+y.options[y.selectedIndex].value+'&';
    }
    
    //check the slider values, if there has been a change, add the change to the parameter string
    if (z[0] != floorplans_data.rent_range.min) {
        paramStr += 'selected_price_range='+z[0]+'-'+z[1];
        price_range_slider.noUiSlider.updateOptions({
            start: [z[0], z[1]]
        });
    } else if(z[1] != floorplans_data.rent_range.max) {
        paramStr += 'selected_price_range='+z[0]+'-'+z[1];
        price_range_slider.noUiSlider.updateOptions({
            start: [z[0], z[1]]
        });
    }
    
    //create the url string
    full_address = location.origin+location.pathname;
    if (paramStr.length > 1) {
        full_address = location.origin+location.pathname+'?'+paramStr;
    }

    //reconstruct the url with the new string
    history.replaceState(
        {},
        document.title,
        full_address
    );

    //reset the parameter object with the new url
    params = new URLSearchParams(location.search);
    filters = [...params.entries()];

    //filter out the floorplans, then construct the new floorplan cards
    floorplans = rp_archive_fp_filterFloorplans(floorplans);
    rp_archive_fp_makeAllCards(floorplans);
    rp_archive_fp_constructBedroomsFilter(all_floorplans_bed_types);

    //if google tag manager js exists, make an event for the new search
    if (typeof ga !== "undefined") { 
        google_tag_events++;

        ga('send', {
            hitType: 'event',
            eventCategory: "Floorplans - Filter",
            eventAction: "Filter Floorplans",
            eventLabel: paramStr,
            eventValue: google_tag_events
        });
    }
}

/**
* @param floorplan array
* @return floorplan array
* takes the given floorplan array and returns a sorted floorplans array based on sort selector
*/
function rp_archive_fp_sortFloorplans(floorplans) {
    // default sort is a rentpress option
    // this block will only ever run once on page load, then value is false and will never run again
    if (default_sort) {
        document.getElementById("floorplan_sort").value = default_sort;
        default_sort = false;
    }

    //see what value is in the selector
    selected_sort = document.getElementById("floorplan_sort").value;

    //based on the selected sort, apply that sort to the array
    switch(selected_sort) {
        case "avail:asc":
            // sorts by rent ascending, then by availability
            floorplans.sort(function(a, b) {
                return a.fpMinRent - b.fpMinRent;
            });
            floorplans.sort(function(a, b) {
                return b.fpAvailUnitCount - a.fpAvailUnitCount;
            });
            break;
        case "rent:asc":
            floorplans.sort(function(a, b) {
                return a.fpMinRent - b.fpMinRent;
            });
            break;
        case "rent:desc":
            floorplans.sort(function(a, b) {
                return b.fpMinRent - a.fpMinRent;
            });
            break;
        case "sqft:asc":
            floorplans.sort(function(a, b) {
                return a.sqft - b.sqft;
            });
            break;
        case "sqft:desc":
            floorplans.sort(function(a, b) {
                return b.sqft - a.sqft;
            });
            break;
        case "beds:asc":
            // sorts by rent ascending, then by number of bedrooms
            floorplans.sort(function(a, b) {
                return a.fpMinRent - b.fpMinRent;
            });
            floorplans.sort(function(a, b) {
                return a.bedCount - b.bedCount;
            });
            break;
        default:
    }
    return floorplans;
}

/**
* has no params or returns
* sets the floorplans that can be selected, or have been selected
*/
function rp_archive_fp_constructBedroomsFilter() {
    //set up the needed variables
    var bed_count_types = all_floorplans_bed_types;
    bedroomChoices = params.getAll('selected_floorplans_beds');

    //sort in ascending order
    bed_count_types.sort(function(a, b){return b - a});

    bedStr = "";

    //for each bed type
    for (var i = bed_count_types.length - 1; i >= 0; i--) {
        // that has been selected in the url, mark the element as checked
        checked = ''
        if (bedroomChoices.includes(bed_count_types[i]+" Bedroom")) {
            checked = 'checked';

        }
        if (bed_count_types[i] == "0" && bedroomChoices.includes("Studio")) {
            checked = 'checked';
        }

        paragraph = "<p>";
        if (checked == 'checked') {
            paragraph = "<p class='rp-is-checked'>";
        }

        //construct the bed type elemements
        if (bed_count_types[i] == 0) {
            bedStr += paragraph+"<label><input type='checkbox' class='rp-input rp-bed-filter' name='selected_floorplans_beds' value='Studio' "+checked+">Studio</label></p>"
        }
        else {
            bedStr += paragraph+"<label><input type='checkbox' class='rp-input rp-bed-filter' name='selected_floorplans_beds' value='"+bed_count_types[i]+" Bedroom' "+checked+"> "+bed_count_types[i]+" Bedroom</label></p>"
        }
    }

    bedStr += "<div class='clearfix'></div>";

    //apply the constructed elements to the dom
    document.getElementById('rp-archive-fp-bed-filter').innerHTML = bedStr;


    bedroom_checkboxes = document.getElementsByClassName('rp-input rp-bed-filter');

    for (var i = 0; i < bedroom_checkboxes.length; i++) {
        bedroom_checkboxes[i].onclick = function() {
            this.parentNode.parentNode.classList.toggle('rp-is-checked');
        }

    }

    
}

/**
* has no params
* @return the uislider object
* constructs the ui slider dynamically
*/
function rp_archive_fp_constructPriceSlider() {
    //gather the existing values
    var price_range_slider = document.getElementById('rp-archive-fp-price-range');
    var input_fp_min_rent = document.getElementById('floorplans_min_rent').value;
    var input_fp_max_rent = document.getElementById('floorplans_max_rent').value;

    //if pricing is disabled on the site, then don't show this element on the dom
    if (floorplans_data["disable_pricing"] == "true") {
        
        document.getElementById('filter-module-section').style.display = "none";
    }
    
    //if the input has selected value, the set them as such
    if (input_fp_min_rent) {
        var start_min=input_fp_min_rent;
    }
    else {
        var start_min=floorplans_data.rent_range.min;
    }

    if (input_fp_max_rent) {
        var start_max=input_fp_max_rent;
    }
    else {
        var start_max=floorplans_data.rent_range.max;
    }

    //call the uislider library
    noUiSlider.create(price_range_slider, {
        start: [start_min, start_max],
        connect: true,
        tooltips: true,
        step: 10,
        range: {
            'min': Number(floorplans_data.rent_range.min),
            'max': Number(floorplans_data.rent_range.max)
        },
        format: {
            to: function (value) {
                return value + '';
            },
            from: function (value) {
                return value.replace(',-', '');
            }
        }
    });
    
    //update the ui slider with the set values
    price_range_slider.noUiSlider.on('update', function( values, handle ) {
        input_fp_min_rent.value=values[0];
        input_fp_max_rent.value=values[1];
    });

    //return the slider object so it doesn't have to be remade to update it
    return price_range_slider;
}

/**
* @param floorplan array
* @return bed type array
* returns each bed type found in the floorplan array
*/
function rp_archive_fp_getUniqueBedTypes(fp) {
    var bed_types = [];

    for (var i = fp.length - 1; i >= 0; i--) {
        bed_type = fp[i]['bedCount'];

        if(bed_types.indexOf(bed_type) == -1) {
            bed_types.push(bed_type);
        }

    }
    return bed_types;
}

/**
* @param floorplan array
* @return floorplan array
* returns filtered out floorplan array
*/
function rp_archive_fp_filterFloorplans(floorplans) {
    //get each of the selected filters from the url 
    price = params.get('selected_price_range');
    dateChangeString = params.get('floorplans_available_by');
    bedroomChoices = params.getAll('selected_floorplans_beds');

    //if one or more bedroom type is selected, then filter out floorplans not selected
    if (bedroomChoices.length > 0) {
        floorplans = rp_archive_fp_filterOutBedrooms(floorplans, bedroomChoices);
    }

    //if a price range is selected, then filter out floorplans that are not in it
    if (price) {
        floorplans = rp_archive_fp_filterOutPrice(floorplans, price);
    }

    //if a date range is selected, then filter out floorplans that are later than it
    if (dateChangeString) {
        floorplans = rp_archive_fp_filterOutDate(floorplans, dateChangeString);
    }

    return floorplans;
}

function rp_archive_fp_filterOutDate(floorplans, dateChangeString) {
    selectedDate = new Date(); 
    if (dateChangeString == 'Next Two Weeks') {
        selectedDate.setDate(selectedDate.getDate()+14);
    }
    if (dateChangeString == 'Next Month') {
        selectedDate.setMonth(selectedDate.getMonth()+2)
        selectedDate.setDate(0);
    }
    if (dateChangeString == 'Next Two Months') {
        selectedDate.setMonth(selectedDate.getMonth()+3)
        selectedDate.setDate(0);
    }

    unit_day = new Date();

    for (var key = floorplans.length - 1; key >= 0; key--) {

        totalUnits = floorplans[key]['units'].length;
        for (var i = totalUnits - 1; i >= 0; i--) {
            
            unit_day.setTime(floorplans[key]['units'][i]['newDate']);

            if (unit_day.getTime() > selectedDate.getTime()) {
                floorplans[key]['units'].splice([i],1);
            } else if (floorplans[key]['units'][i]['is_available_on'] == "1970-01-01") {
                floorplans[key]['units'].splice([i],1);
            }
        }

        if (floorplans[key]['units'].length == 0) {
            floorplans.splice([key],1);
        } else if (floorplans_data['show_all_units'] == 'true') {
            floorplans[key]['fpAvailUnitCountDisplay'] = (totalUnits > 1 ? totalUnits+" Apartments" : totalUnits+" Apartment" );
        } else if (floorplans_data['show_waitlist'] && floorplans[key]['units'].length == 0) {
            floorplans[key]['fpAvailUnitCountDisplay'] = "Join Waitlist";
        } else {
            floorplans[key]['fpAvailUnitCountDisplay'] = floorplans[key]['units'].length+" Available";
        }
    }

    return floorplans;
}

function rp_archive_fp_filterOutPrice(floorplans, price) {
    price = price.split("-");
    min = price[0];
    max = price[1];
    for (var key = floorplans.length - 1; key >= 0; key--) {
        if (floorplans[key]['fpMinRent'] > max || floorplans[key]['fpMinRent'] < min) {
            floorplans.splice([key],1);
        }
    }

    return floorplans;
}

function rp_archive_fp_filterOutBedrooms(floorplans, bedroomChoices) {
    if (!bedroomChoices.includes('Studio')) {
        for (var key = floorplans.length - 1; key >= 0; key--) {
            if (floorplans[key]['bedCount'] == "0") {
                floorplans.splice([key],1);
            }
        }
    }
    if (!bedroomChoices.includes('1 Bedroom')) {
        for (var key = floorplans.length - 1; key >= 0; key--) {
            if (floorplans[key]['bedCount'] == "1") {
                floorplans.splice([key],1);
            }
        }
    }
    if (!bedroomChoices.includes('2 Bedroom')) {
        for (var key = floorplans.length - 1; key >= 0; key--) {
            if (floorplans[key]['bedCount'] == "2") {
                floorplans.splice([key],1);
            }
        }
    }
    if (!bedroomChoices.includes('3 Bedroom')) {
        for (var key = floorplans.length - 1; key >= 0; key--) {
            if (floorplans[key]['bedCount'] == "3") {
                floorplans.splice([key],1);
            }
        }
    }
    if (!bedroomChoices.includes('4 Bedroom')) {
        for (var key = floorplans.length - 1; key >= 0; key--) {
            if (floorplans[key]['bedCount'] == "4") {
                floorplans.splice([key],1);
            }
        }
    }
    if (!bedroomChoices.includes('5 Bedroom')) {
        for (var key = floorplans.length - 1; key >= 0; key--) {
            if (floorplans[key]['bedCount'] == "5") {
                floorplans.splice([key],1);
            }
        }
    }

    return floorplans;
}

/**
* @param floorplan array
* this function iterates through the array and constructs a card for each one
*/
function rp_archive_fp_makeAllCards(floorplans){
    strVar = "";

    if (floorplans.length > 0) {
        document.getElementById('rp-archive-fp-data').classList.remove('rp-no-results');
        floorplans = rp_archive_fp_sortFloorplans(floorplans);
        floorplans.forEach(rp_archive_fp_makeFpCard);
    } else {
        document.getElementById('rp-archive-fp-data').classList.add('rp-no-results');
        rp_archive_fp_makeNoFloorplansMessage();
    }

    

    

    //apply the html string to the dom
    document.getElementById("floorplans_count").innerHTML = floorplans.length;
    document.getElementById("floorplan_cards").innerHTML = strVar;
}

/**
* @param floorplan
* creates the html elements for the floorplan given
*/
function rp_archive_fp_makeFpCard(floorplan) {
    strVar += "<div class='is-rp-fp'>";
    strVar += " <a href="+floorplan['post_url']+">";
    strVar += "     <figure>";
    strVar += "         <img src="+floorplan['fpImg']['image']+" alt='"+floorplan['fpImg']['alt']+"' >";
    strVar += "     <\/figure>";
    strVar += "     <footer class='rp-fp-details'>";
    strVar += "         <h4>"+floorplan['post_title']+"<\/h4>";
    strVar += "         <p>"+floorplan['displaySqft']+"<\/p>";
    strVar += "         <p class='rp-starting-at'>";
    strVar += "             <span>"+floorplan['displayRent']+"<\/span>";
    strVar += "             <span class='rp-num-avail rp-primary-accent'>"+floorplan['fpAvailUnitCountDisplay']+"<\/span>";
    strVar += "         <\/p>";
    strVar += "     <\/footer>";
    strVar += " <\/a>";
    strVar += "<\/div>";

}

function rp_archive_fp_makeNoFloorplansMessage() {
    strVar += "<div class='rp-no-results-wrapper'>";
    strVar += "<p class='rp-primary-accent'>No Apartments Found</p>";
    strVar += "<p>Please try another search or <a class='rp-primary-accent' href='"+location.origin+"/contact'>Contact Us</a>.</p>";
    strVar += "<\/div>";
}

function rp_archive_fp_resetValues() {
    all_floorplans_data = JSON.parse(all_floorplans_data_encoded);
    floorplans_data = all_floorplans_data['data'];
    floorplans = all_floorplans_data['all_floorplans'];
    all_floorplans_bed_types = rp_archive_fp_getUniqueBedTypes(all_floorplans_data['all_floorplans']);
}
