<?php

class rentPress_SettingsTabs_GeneralConfig{

	public static $menu_slug = 'rentPress-settings';

	public static $optionGroup = 'rentPress_wordpress_option_group';

	public static $apiCredentialsSettingsSectionID = 'rentPress_api_credentials';

	public static $isSiteAboutASinglePropertySettingsSectionID = 'rentPress_is_site_about_a_single_property';

	public static $templateOverrideSectionID = 'rentPress_override_setting';

	public static $singleFloorplanTemplateOverrideSectionID = 'sfp_rentPress_override_setting';

	public static $floorplanGridTemplateOverrideSectionID = 'fg_rentPress_override_setting';

	public function __construct() {
		$this->options = new rentPress_Options();

		$this->wp_menu_args = (object) [
			'parent_slug' => 'options-general.php',
			'page_title' =>  'RentPress',
			'menu_title' =>  'RentPress',
			'capability' => 'manage_options',
			'menu_slug' => 'rentPress-settings',
		];

		$this->fields_keys = [
			'api_token',
			'api_username',
			'is_site_about_a_single_property',
			'template_override',
			'templates_accent_color',
			'override_single_property_template_file',
			'override_single_floorplan_template_file',
			'override_unit_visibility',
			'override_single_floorplan_template_title',
			'hide_floorplan_availability_counter',
			'hide_floorplans_without_availability',
			'override_archive_floorplans_template_file',
			'archive_floorplans_default_sort',
			'single_floorplan_content_position',
			'archive_floorplan_content_position',
			'override_how_floorplan_pricing_is_display',
			'override_apply_links_targets',
			'override_request_link',
			'single_floorplan_request_more_info_url',
			'show_waitlist_ctas',
			'show_waitlist_override_url',
		];

		$this->fields=[];

		if (is_array($this->fields_keys)) {

			foreach ($this->fields_keys as $field_key) {

				$this->fields[ $field_key ] = (object) [

					'name' => $this->options->prefix($field_key),
					'value' => $this->options->getOption($field_key),

				];

			}

		}

		$this->fields = (object) $this->fields;

		add_action( 'admin_menu', [$this, 'generateMainOptionsPage'], 20);

		add_action( 'admin_init', [$this, 'wp_setting_sections_and_fields'], 20 );
	}

	/**
	 * Create the main RentPress plugin options page to be visible in the WP admin menu
	 * @return void
	 */
	public function generateMainOptionsPage()
	{
		add_menu_page(
			$this->wp_menu_args->page_title,
			$this->wp_menu_args->menu_title,
			$this->wp_menu_args->capability,
			$this->wp_menu_args->menu_slug,
			[ $this, 'render_settings_page' ],
			RENTPRESS_PLUGIN_ASSETS . '/images/icon.png',
			5
		);
	}

	/**
	 * Render the settings page and fields for RentPress general settings
	 * @return void
	 */
	public function render_settings_page()
	{
		$common_html=new rentPress_SettingsTabs_CommonHtml();

		$common_html->openingOptionsWrapper(); ?>
		    <h1>RentPress: General Settings</h1>
		    <?php
		    settings_errors();
		    $common_html->displayOptionsTabs(); ?>

		    <form method="post" action="options.php" enctype="multipart/form-data">
		    	<?php
		        settings_fields(self::$optionGroup);
		        do_settings_sections($this->wp_menu_args->menu_slug);
		        submit_button(); ?>
		    </form>
		<?php
		$common_html->closingOptionsWrapper();
	}

	public function wp_setting_sections_and_fields() {
		add_settings_section(
			self::$apiCredentialsSettingsSectionID,
			'API Credentials',
			function() { echo '<p>Can be obtained by purchasing a RentPress subscription from <a href="https://30lines.com">30 Lines</a>.</p>'; },
			$this->wp_menu_args->menu_slug
		);
			add_settings_field(
				$this->fields->api_token->name,
				'API Token',
				[$this, 'rentPress_api_token'],
				$this->wp_menu_args->menu_slug,
				self::$apiCredentialsSettingsSectionID
			);

			add_settings_field(
				$this->fields->api_username->name,
				'Username',
				[$this, 'rentPress_api_username'],
				$this->wp_menu_args->menu_slug,
				self::$apiCredentialsSettingsSectionID
			);

			register_setting(self::$optionGroup, $this->fields->api_token->name);
			register_setting(self::$optionGroup, $this->fields->api_username->name);

		add_settings_section(
			self::$isSiteAboutASinglePropertySettingsSectionID,
			'Single Property Site',
			function() { echo '<p>Check this if your website promoting a single property. This will enable built-in templates and can assist with overall site load speeds.</p>'; },
			$this->wp_menu_args->menu_slug
		);

			add_settings_field(
				$this->fields->is_site_about_a_single_property->name,
				'Single Property Website',
				[$this, 'rentPress_site_is_about_single_property'],
				$this->wp_menu_args->menu_slug,
				self::$isSiteAboutASinglePropertySettingsSectionID
			);

			register_setting(self::$optionGroup, $this->fields->is_site_about_a_single_property->name);

		/* Override single-floorplans.php and single-properties.php with plugin default templates */

		add_settings_section(
			self::$templateOverrideSectionID,
			'RentPress Templates',
			[$this, 'template_override_section_description'],
			$this->wp_menu_args->menu_slug
		);		

			add_settings_field(
				$this->fields->override_single_floorplan_template_file->name,
				'Use Single Floor Plan Template',
				[$this, 'rentPress_override_single_floorplan_file'],
				$this->wp_menu_args->menu_slug,
				self::$templateOverrideSectionID
			);

			add_settings_field(
				$this->fields->override_archive_floorplans_template_file->name,
				'Use Floor Plans Grid Template',
				[$this, 'rentPress_override_archive_floorplans_file'],
				$this->wp_menu_args->menu_slug,
				self::$templateOverrideSectionID
			);

			add_settings_field(
				$this->fields->templates_accent_color->name,
				'Accent Color',
				[$this, 'rentPress_templates_accent_color'],
				$this->wp_menu_args->menu_slug,
				self::$templateOverrideSectionID
			);

			add_settings_field(
				$this->fields->override_unit_visibility->name,
				'Unit Visibility',
				[$this, 'rentPress_override_unit_visibility'],
				$this->wp_menu_args->menu_slug,
				self::$templateOverrideSectionID
			);

			add_settings_field(
				$this->fields->hide_floorplan_availability_counter->name,
				'Floor Plan Availability Counter',
				[$this, 'rentPress_hide_floorplan_availability_counter'],
				$this->wp_menu_args->menu_slug,
				self::$templateOverrideSectionID,
				[
		        	'class' => 'field-group-3'
		    	]
			);

			add_settings_field(
				$this->fields->hide_floorplans_without_availability->name,
				'Floor Plans with No Availability',
				[$this, 'rentPress_hide_floorplans_without_availability'],
				$this->wp_menu_args->menu_slug,
				self::$templateOverrideSectionID,
				[
		        	'class' => 'field-group-3'
		    	]
			);

		add_settings_section(
			self::$singleFloorplanTemplateOverrideSectionID,
			'Single Floor Plan Template',
			[$this, 'single_floorplan_template_section_description'],
			$this->wp_menu_args->menu_slug
		);		
			add_settings_field(
				$this->fields->single_floorplan_content_position->name,
				'Single Floor Plan Content Position',
				[$this, 'rentPress_single_floorplan_content_position'],
				$this->wp_menu_args->menu_slug,
				self::$singleFloorplanTemplateOverrideSectionID,
				[
		        	'class' => 'field-group-3'
		    	]
			);

			add_settings_field(
				$this->fields->override_single_floorplan_template_title->name,
				'Floor Plan Title',
				[$this, 'rentPress_override_single_floorplan_title'],
				$this->wp_menu_args->menu_slug,
				self::$singleFloorplanTemplateOverrideSectionID,
				[
		        	'class' => 'field-group-3'
		    	]
			);

			add_settings_field(
				$this->fields->override_how_floorplan_pricing_is_display->name,
				'Floor Plan Price',
				[$this, 'rentPress_override_how_floorplan_pricing_is_display_field'],
				$this->wp_menu_args->menu_slug,
				self::$singleFloorplanTemplateOverrideSectionID,
				[
					'class' => 'field-group-3'
				]
				);

			add_settings_field(
				$this->fields->override_apply_links_targets->name,
				"Apply Link Opens In",
				[$this, 'rentPress_override_apply_links_targets_field'],
				$this->wp_menu_args->menu_slug,
				self::$singleFloorplanTemplateOverrideSectionID,
				[
		        	'class' => 'field-group-3'
		    	]
			);

			add_settings_field(
				$this->fields->override_request_link->name,
				'"Request More Info" URL',
				[$this, 'override_request_link_field'],
				$this->wp_menu_args->menu_slug,
				self::$singleFloorplanTemplateOverrideSectionID,
				[
		        	'class' => 'field-group-3'
		    	]
			);

	    	add_settings_field(
		        $this->fields->single_floorplan_request_more_info_url->name,
		        '"Request More Info" URL Override',
		        [$this, 'request_info_url_field'],
		        $this->wp_menu_args->menu_slug,
		        self::$singleFloorplanTemplateOverrideSectionID,
		        [
		        	'class' => 'field-group-2'
		    	]
		    );

		    add_settings_field(
				$this->fields->show_waitlist_ctas->name,
				'Show Waitlist CTAs',
				[$this, 'show_waitlist_ctas_field'],
				$this->wp_menu_args->menu_slug,
				self::$singleFloorplanTemplateOverrideSectionID,
				[
		        	'class' => 'field-group-3'
		    	]
			);

	    	add_settings_field(
		        $this->fields->show_waitlist_override_url->name,
		        '"Show Waitlist CTAs" URL Override',
		        [$this, 'show_waitlist_override_url_field'],
		        $this->wp_menu_args->menu_slug,
		        self::$singleFloorplanTemplateOverrideSectionID,
		        [
		        	'class' => 'field-group-6'
		    	]
		    );

		add_settings_section(
			self::$floorplanGridTemplateOverrideSectionID,
			'Floor Plan Grid Template',
			[$this, 'floorplan_grid_section_description'],
			$this->wp_menu_args->menu_slug
		);

			add_settings_field(
				$this->fields->archive_floorplans_default_sort->name,
				'Default Sort',
				[$this, 'rentPress_floorplans_default_sort'],
				$this->wp_menu_args->menu_slug,
				self::$floorplanGridTemplateOverrideSectionID,
				[
		        	'class' => 'field-group-4'
		    	]
			);
			add_settings_field(
				$this->fields->archive_floorplan_content_position->name,
				'Floor Plans Grid Content Position',
				[$this, 'rentPress_archive_floorplan_content_position'],
				$this->wp_menu_args->menu_slug,
				self::$floorplanGridTemplateOverrideSectionID,
				[
		        	'class' => 'field-group-4'
		    	]
			);

			

			// add_settings_field(
			// 	$this->fields->override_single_property_template_file->name,
			// 	'Single Property Templates',
			// 	[$this, 'rentPress_override_single_property_file'],
			// 	$this->wp_menu_args->menu_slug,
			// 	self::$templateOverrideSectionID
			// );
			
	    	
	    	register_setting(self::$optionGroup, $this->fields->template_override->name);
			register_setting(self::$optionGroup, $this->fields->templates_accent_color->name);
			register_setting(self::$optionGroup, $this->fields->override_single_property_template_file->name);
			register_setting(self::$optionGroup, $this->fields->override_single_floorplan_template_file->name);
			register_setting(self::$optionGroup, $this->fields->override_how_floorplan_pricing_is_display->name);
			register_setting(self::$optionGroup, $this->fields->override_apply_links_targets->name);
			register_setting(self::$optionGroup, $this->fields->override_unit_visibility->name);
			register_setting(self::$optionGroup, $this->fields->hide_floorplan_availability_counter->name);
			register_setting(self::$optionGroup, $this->fields->hide_floorplans_without_availability->name);
			register_setting(self::$optionGroup, $this->fields->override_single_floorplan_template_title->name);
			register_setting(self::$optionGroup, $this->fields->override_archive_floorplans_template_file->name);
			register_setting(self::$optionGroup, $this->fields->archive_floorplans_default_sort->name);
			register_setting(self::$optionGroup, $this->fields->single_floorplan_content_position->name);
			register_setting(self::$optionGroup, $this->fields->archive_floorplan_content_position->name);
			register_setting(self::$optionGroup, $this->fields->override_request_link->name);
			register_setting(self::$optionGroup, $this->fields->single_floorplan_request_more_info_url->name);
			register_setting(self::$optionGroup, $this->fields->show_waitlist_ctas->name);
			register_setting(self::$optionGroup, $this->fields->show_waitlist_override_url->name);

	}

	/** General settings field renderings */

	/**
	 * Settings Section: API Credentials
	 * @return string [HTML of settings input]
	 */
	public function rentPress_api_token()
	{
		?>
			<input type='text'
				name='<?php echo $this->fields->api_token->name; ?>'
				value='<?php echo $this->fields->api_token->value; ?>'
				placeholder='API Token'>

		<?php
	}

	public function rentPress_api_username()
	{
		?>
			<input type='text'
				name='<?php echo $this->fields->api_username->name; ?>'
				value='<?php echo $this->fields->api_username->value; ?>'
				placeholder='API Username'>
		<?php
	}

	public function rentPress_site_is_about_single_property()
	{

		$isChecked = checked( $this->fields->is_site_about_a_single_property->value, 'true', false );
		?>
			<label>

				<input type='checkbox'
					name='<?php echo $this->fields->is_site_about_a_single_property->name; ?>'
					value='true'
					<?php echo $isChecked; ?>>

				This website is for a single property
			</label>
		<?php
	}

	public function rentPress_templates_accent_color() {

		echo "<input type='color' name='{$this->fields->templates_accent_color->name}' value='{$this->fields->templates_accent_color->value}'>";

	}

	// public function rentPress_override_single_property_file()
	// {
	// 	$options=[
	// 		"Use Custom Theme" => 'current-theme',
	// 		'Single Property Template' => RENTPRESS_PLUGIN_DIR . 'templates/Properties/single-property-basic.php',
	// 	];
	//
	// 	echo '<select name="'. $this->fields->override_single_property_template_file->name .'">';
	//
	// 		foreach ($options as $text => $optValue) {
	//
	// 			$isSelected=selected($this->fields->override_single_property_template_file->value, $optValue, false);
	//
	// 			echo '<option value="'. esc_attr($optValue) .'" '. $isSelected .'>'. $text .'</option>';
	//
	// 		}
	//
	// 	echo '</select>';
	// }

	public function rentPress_override_single_floorplan_file()
	{
		$isChecked = checked( $this->fields->override_single_floorplan_template_file->value, RENTPRESS_PLUGIN_DIR . 'templates/FloorPlans/single-floorplan-basic.php', false );
		echo "<input id='rentpress_single_floorplan_setting' type='checkbox' name='". $this->fields->override_single_floorplan_template_file->name ."' value='". RENTPRESS_PLUGIN_DIR . "templates/FloorPlans/single-floorplan-basic.php' {$isChecked}>";
	}

	public function rentPress_override_how_floorplan_pricing_is_display_field() {
		$options=[
			"Starting At" => 'starting-at',
			'Range' => 'range',
		];

		echo '<select name="'. $this->fields->override_how_floorplan_pricing_is_display->name .'">';

			foreach ($options as $text => $optValue) {

				$isSelected=selected($this->fields->override_how_floorplan_pricing_is_display->value, $optValue, false);

				echo '<option value="'. esc_attr($optValue) .'" '. $isSelected .'>'. $text .'</option>';

			}

		echo '</select>';


	}

	public function rentPress_override_apply_links_targets_field() {
		$options=[
			"Same Window" => '_self',
			'New Window' => '_blank',
		];

		echo '<select name="'. $this->fields->override_apply_links_targets->name .'">';

			foreach ($options as $text => $optValue) {

				$isSelected=selected($this->fields->override_apply_links_targets->value, $optValue, false);

				echo '<option value="'. esc_attr($optValue) .'" '. $isSelected .'>'. $text .'</option>';

			}

		echo '</select>';
	}

	public function rentPress_override_single_floorplan_title () {

		$isChecked = checked( $this->fields->override_single_floorplan_template_title->value, 'true', false );
		echo "
			<label>
				<input type='checkbox' name='{$this->fields->override_single_floorplan_template_title->name}' value='true' {$isChecked}>
				Use Floor Plan's Marketing Name
			</label>
		";

	}	

	public function rentPress_hide_floorplan_availability_counter () {

		$isChecked = checked( $this->fields->hide_floorplan_availability_counter->value, 'true', false );
		echo "
			<label>
				<input type='checkbox' name='{$this->fields->hide_floorplan_availability_counter->name}' value='true' {$isChecked}>
				Hide floor plan availability counter
			</label>
		";

	}	

	public function rentPress_hide_floorplans_without_availability () {

		$isChecked = checked( $this->fields->hide_floorplans_without_availability->value, 'true', false );
		echo "
			<label>
				<input type='checkbox' name='{$this->fields->hide_floorplans_without_availability->name}' value='true' {$isChecked}>
				Hide floor plans with no availability
			</label>
		";

	}

	// public function rentPress_override_unit_visibility() {

	// 	$isChecked = checked( $this->fields->override_unit_visibility->value, 'true', false );
	// 	echo "
	// 		<label>
	// 			<input type='checkbox' name='{$this->fields->override_unit_visibility->name}' value='true' {$isChecked}>
	// 			Show All Units
	// 		</label>
	// 	";

	// 	if ($this->options->getOption('disable_pricing_on_floorplan_with_no_available_units') === 'true') {

	// 		echo '<p><small style="color:red;">Warning: Having This Checked, may conflict with having the disable pricing for floorplans with no available units turned on!</small></p>';

	// 	}

	// }

	public function rentPress_override_unit_visibility()
	{
		$options=[
			"Show units with date and/or availability status" => 'unit_visibility_1',
			"Show units with availability status" => 'unit_visibility_2',
			"Show units only available as of today" => 'unit_visibility_3',
			"Show units available as of today plus Lookahead" => 'unit_visibility_4',
			"Show all units" => 'unit_visibility_5'
		];

		echo '<select name="'. $this->fields->override_unit_visibility->name .'">';

			foreach ($options as $text => $optValue) {

				$isSelected=selected($this->fields->override_unit_visibility->value, $optValue, false);

				echo '<option value="'. esc_attr($optValue) .'" '. $isSelected .'>'. $text .'</option>';

			}

		echo '</select>';
	}

	public function rentPress_override_archive_floorplans_file()
	{

		$isChecked = checked( $this->fields->override_archive_floorplans_template_file->value, RENTPRESS_PLUGIN_DIR . 'templates/FloorPlans/archive-floorplans-basic.php', false );
		echo "<input id='rentPress_archive_floorplan_setting' type='checkbox' name='". $this->fields->override_archive_floorplans_template_file->name ."' value='". RENTPRESS_PLUGIN_DIR . "templates/FloorPlans/archive-floorplans-basic.php' {$isChecked}>";
	}

	public function rentPress_floorplans_default_sort()
	{
		$options=[
			"Soonest Available" => 'avail:asc',
			"Rent: Low to High" => 'rent:asc',
			"Rent: High to Low" => 'rent:desc',
			"SQFT: Low To High" => 'sqft:asc',
			"SQFT: High to Low" => 'sqft:desc',
			"Bedrooms" => 'beds:asc'
		];

		echo '<select name="'. $this->fields->archive_floorplans_default_sort->name .'">';

			foreach ($options as $text => $optValue) {

				$isSelected=selected($this->fields->archive_floorplans_default_sort->value, $optValue, false);

				echo '<option value="'. esc_attr($optValue) .'" '. $isSelected .'>'. $text .'</option>';

			}

		echo '</select>';
	}

	public function rentPress_single_floorplan_content_position()
	{
		$options=[
			"Top of Page" => 'single_floorplan_content_top',
			"Bottom of Page" => 'single_floorplan_content_bottom'
		];

		echo '<select name="'. $this->fields->single_floorplan_content_position->name .'">';

			foreach ($options as $text => $optValue) {

				$isSelected=selected($this->fields->single_floorplan_content_position->value, $optValue, false);

				echo '<option value="'. esc_attr($optValue) .'" '. $isSelected .'>'. $text .'</option>';

			}

		echo '</select>';
	}

	public function rentPress_archive_floorplan_content_position()
	{
		$options=[
			"Top of Page" => 'archive_floorplan_content_top',
			"Bottom of Page" => 'archive_floorplan_content_bottom'
		];

		echo '<select name="'. $this->fields->archive_floorplan_content_position->name .'">';

			foreach ($options as $text => $optValue) {

				$isSelected=selected($this->fields->archive_floorplan_content_position->value, $optValue, false);

				echo '<option value="'. esc_attr($optValue) .'" '. $isSelected .'>'. $text .'</option>';

			}

		echo '</select>';
	}

	public function template_override_section_description()
	{
		echo '<p>Toggle on/off the default templates that come with this plugin. Uncheck checkboxes to build custom templates. <a href="https://30lines.com/rentpress/documentation/" target="_blank" rel="noopener" >Click here</a> for documentation.</p>';
	}	
	
	public function single_floorplan_template_section_description()
	{
		echo '<p>Options specific to the Single Floor Plan template.</p>';
	}	

	public function floorplan_grid_section_description()
	{
		echo '<p>Options specific to the Floor plans Grid template.</p>';
	}

	public function override_request_link_field()
	{
		$isChecked = checked( $this->fields->override_request_link->value, 'true', false );

		echo '<label for="override_request_link">';
			echo "<input id='override_request_link' type='checkbox' name='{$this->fields->override_request_link->name}' value='true' {$isChecked}>";

			echo '<i>Override default /contact/ link for "Request More Info" button</i>';
		echo '</label>';
	}

	public function request_info_url_field() {

		$default_url = site_url().'/contact';
		echo "<input class='field-group-2-input' type='url' name='{$this->fields->single_floorplan_request_more_info_url->name}' value='{$this->fields->single_floorplan_request_more_info_url->value}' placeholder='$default_url'>";
		echo '<p><small>Enter the entire URL that you would like the "Request More Info" button to link to.</small></p>';
	}

	public function show_waitlist_ctas_field()
	{
		$isChecked = checked( $this->fields->show_waitlist_ctas->value, 'true', false );

		echo '<label for="show_waitlist_ctas">';
			echo "<input id='show_waitlist_ctas' type='checkbox' name='{$this->fields->show_waitlist_ctas->name}' value='true' {$isChecked}>";
		echo '</label>';
	}

	public function show_waitlist_override_url_field() {

		$default_url = site_url().'/waitlist';
		echo "<input class='field-group-2-input' type='url' name='{$this->fields->show_waitlist_override_url->name}' value='{$this->fields->show_waitlist_override_url->value}' placeholder='$default_url'>";
		echo '<p><small>Override default /waitlist/ link for "Join Our Waitlist" button, by entering the entire URL that you would like to link to.</small></p>';
	}

}