<?php

class rentPress_SettingsTabs_GoogleConfig extends rentPress_Base_WpSettingsSubPage{

	public static $googleConfigSectionID='rentPress_google_configuration';
	public static $optionGroup = 'rentPress_google_config_option_group';

	public function __construct() {
		$this->wp_menu_args = [
			'menu_title' => 'Google Maps API',
			'page_title' => 'Google Maps API',
			'page_slug' => 'rentPress_google_maps_settings'
		];

		$this->fields_keys =[

			'google_api_token',
			'google_js_default_map_center_latitude',
			'google_js_default_map_center_longitude',
			'google_js_map_unit_of_distance',

		];
		parent::__construct();
	}

	public function render_settings_page() {
		$common_html=new rentPress_SettingsTabs_CommonHtml();

		$common_html->openingOptionsWrapper(); ?>
		    <h1>RentPress: Google Configuration</h1>
		    <?php
		    settings_errors();
		    $common_html->displayOptionsTabs(); ?>

		    <form method="post" action="options.php" enctype="multipart/form-data">
		        <?php settings_fields(self::$optionGroup); ?>

		        <?php do_settings_sections($this->wp_menu_args->page_slug);?>
		        <?php submit_button();?>
		    </form>
		<?php $common_html->closingOptionsWrapper();
	}

	public function wp_setting_sections_and_fields() {

	    add_settings_section(
	        self::$googleConfigSectionID,
	        'Google JS API Configuration',
			function() {
				echo '<p>You can find the API key from your <a target="_blank" href="https://developers.google.com/maps/documentation/javascript/">Google Map Developer console</a>.</p>';
			},
	        $this->wp_menu_args->page_slug
	    );

	    add_settings_field(
	        $this->fields->google_api_token->name,
	        'Google JS API Token',
	        [$this, 'rentPress_google_js_api_token'],
	        $this->wp_menu_args->page_slug,
	        self::$googleConfigSectionID
	    );

	    add_settings_field(
	        $this->fields->google_js_default_map_center_latitude->name,
	        'Default Center: Latitude',
	        [$this, 'google_js_default_map_center_latitude'],
	        $this->wp_menu_args->page_slug,
	        self::$googleConfigSectionID
	    );

	    add_settings_field(
	        $this->fields->google_js_default_map_center_longitude->name,
	        'Default Center: Longitude',
	        [$this, 'google_js_default_map_center_longitude'],
	        $this->wp_menu_args->page_slug,
	        self::$googleConfigSectionID
	    );

	    add_settings_field(
	        $this->fields->google_js_map_unit_of_distance->name,
	        'Preferred Unit of Measurement',
	        [$this, 'rentPress_google_js_map_unit_of_distance'],
	        $this->wp_menu_args->page_slug,
	        self::$googleConfigSectionID
	    );

		register_setting(self::$optionGroup, $this->fields->google_api_token->name);
		register_setting(self::$optionGroup, $this->fields->google_js_default_map_center_latitude->name);
		register_setting(self::$optionGroup, $this->fields->google_js_default_map_center_longitude->name);
		register_setting(self::$optionGroup, $this->fields->google_js_map_unit_of_distance->name);

	}

	public function rentPress_google_js_api_token()
	{
		echo "<input type='text' name='{$this->fields->google_api_token->name}' value='{$this->fields->google_api_token->value}' placeholder='e.g. AIzmSyBB2ND1X4K-LBkWS18uF2oKKinMINxFzWA'>";
	}

	public function google_js_default_map_center_latitude()
	{
		echo "<input type='text' name='{$this->fields->google_js_default_map_center_latitude->name}' value='{$this->fields->google_js_default_map_center_latitude->value}' placeholder='e.g. 34.023423'>";
	}

	public function google_js_default_map_center_longitude()
	{
		echo "<input type='text' name='{$this->fields->google_js_default_map_center_longitude->name}' value='{$this->fields->google_js_default_map_center_longitude->value}' placeholder='e.g. -83.003242124'>";
	}

	public function rentPress_google_js_map_unit_of_distance()
	{
		$distanceOptions = ['M', 'K'];

		echo "<div class='google-map-unit-of-measuremtn-selection-options'>";
			echo "<select name='{$this->fields->google_js_map_unit_of_distance->name}'>";
				foreach ( $distanceOptions as $unitOfMeasurement ) :

					$isSelected = selected($unitOfMeasurement, $this->fields->google_js_map_unit_of_distance->value, false);

					echo "<option value='{$unitOfMeasurement}' {$isSelected}>";
						echo ($unitOfMeasurement == 'K' ? 'Kilometers' : 'Miles');
					echo '</option>';

				endforeach;
			echo '</select>';
		echo '</div>';
	}
}
