<?php

class rentPress_SettingsTabs_IntegrationsConfig extends rentPress_Base_WpSettingsSubPage {

	public static $integrationsConfigSectionID ='rentPress_integrations_configuration';

	public static $optionGroup = 'rentPress_integrations_config_option_group';

	public static $otherIntegrationsSectionID = 'rentPress_other_integrations';

	public function __construct() {
		$this->wp_menu_args = [
			'menu_title' => 'Integrations',
			'page_title' => 'Integrations',
			'page_slug' => 'rentPress_integrations_settings'
		];


		$this->fields_keys=[
			'is_appointments_installed',
			'tour_cta_button',
			'override_cta_link',
			'single_floorplan_schedule_a_tour_url',
		];

		$this->is_appointments_active=false;

		if ( function_exists('is_plugin_active')) {
			$this->is_appointments_active=( is_plugin_active( 'appointments/appointments.php' ) );
		}

		parent::__construct();
	}

	public function render_settings_page() {
		$common_html=new rentPress_SettingsTabs_CommonHtml();

		$common_html->openingOptionsWrapper(); ?>
		    <h1>RentPress: Integrations Configuration</h1>
		    <?php
		    settings_errors();
		    $common_html->displayOptionsTabs(); ?>

		    <p><i>**Applying changes to pricing and availability settings will require a manual re-sync to see changes immediately. Otherwise, the hourly auto-resync will take care of it for you.</i></p>

		    <form method="post" action="options.php" enctype="multipart/form-data">
		        <?php settings_fields(self::$optionGroup); ?>

		        <?php do_settings_sections($this->wp_menu_args->page_slug) ;?>
		        <?php submit_button() ;?>
		    </form>
		<?php $common_html->closingOptionsWrapper();
	}

	public function wp_setting_sections_and_fields() {

		add_settings_section(
	        self::$integrationsConfigSectionID,
	        'Appointments+',
			function() { echo '<p>Appointments+ is a tour scheduling plugin available from WPMU Dev. RentPress will add a "Schedule A Tour" CTA button to floor plan templates when the plugin is intalled and active. <a href="https://wordpress.org/plugins/appointments/" target="_blank" rel=”noopener noreferrer">Click here to get it</a></p>'; },
	        $this->wp_menu_args->page_slug
	    );

	    add_settings_field(
	        $this->fields->is_appointments_installed->name,
	        'Appointments+',
	        [$this, 'is_appointments_installed'],
	        $this->wp_menu_args->page_slug,
	        self::$integrationsConfigSectionID
	    );

	    register_setting(self::$optionGroup, $this->fields->is_appointments_installed->name);

		if ($this->is_appointments_active) {
		   	add_settings_field(
		        $this->fields->tour_cta_button->name,
		        'Tour CTA Button',
		        [$this, 'show_tour_cta_button'],
		        $this->wp_menu_args->page_slug,
		        self::$integrationsConfigSectionID
		    );

		    add_settings_field(
		        $this->fields->override_cta_link->name,
		        'Override CTA Link',
		        [$this, 'override_cta_link_href'],
		        $this->wp_menu_args->page_slug,
		        self::$integrationsConfigSectionID
		    );

		    	add_settings_field(
			        $this->fields->single_floorplan_schedule_a_tour_url->name,
			        'Tour URL Override',
			        [$this, 'tour_url_override_link'],
			        $this->wp_menu_args->page_slug,
			        self::$integrationsConfigSectionID,
			        [
			        	'class' => 'field-group-1'
			    	]
			    ); 			

		    register_setting(self::$optionGroup, $this->fields->tour_cta_button->name);
		    register_setting(self::$optionGroup, $this->fields->override_cta_link->name);
		    register_setting(self::$optionGroup, $this->fields->single_floorplan_schedule_a_tour_url->name);

		}

	    // add_settings_section(
	    //     self::$otherIntegrationsSectionID,
	    //     'Other Future Integrations etc',
	    //     function() {
			//
			// },
	    //     $this->wp_menu_args->page_slug
	    // );

	}
	public function is_appointments_installed() {
		if ( $this->is_appointments_active ) {
			echo "<b style='color: #59aa0f;'>Installed</b>";
			echo '<input id="is_appointments_installed" type="hidden" name="{$this->fields->is_appointments_installed->name}" value="true">';
		} else {
			echo "<b style='color: #f2571a;'>Not Installed</b>";
			echo '<input id="is_appointments_installed" type="hidden" name="{$this->fields->is_appointments_installed->name}" value="true">';
		}
	}

	public function show_tour_cta_button()
	{
		$isChecked = checked( $this->fields->tour_cta_button->value, 'true', false );

		echo '<label for="tour_cta_button">';
			echo "<input id='tour_cta_button' type='checkbox' name='{$this->fields->tour_cta_button->name}' value='true' {$isChecked}>";

			echo '<i>Show "Schedule A Tour" on floor plan pages</i>';
		echo '</label>';
	}

	public function override_cta_link_href()
	{
		$isChecked = checked( $this->fields->override_cta_link->value, 'true', false );

		echo '<label for="override_cta_link">';
			echo "<input id='override_cta_link' type='checkbox' name='{$this->fields->override_cta_link->name}' value='true' {$isChecked}>";

			echo '<i>Override default /tour/ link for "Schedule A Tour" CTA</i>';
		echo '</label>';
	}

		public function tour_url_override_link() {

		echo "<input class='field-group-1-input' type='url' name='{$this->fields->single_floorplan_schedule_a_tour_url->name}' value='{$this->fields->single_floorplan_schedule_a_tour_url->value}' placeholder='https://www.example.com'>";
		echo '<p><small>Enter the entire URL that you would like the "Schedule A Tour" CTA to link to.</small></p>';

	}

}
