<?php

class rentPress_ShortCodes_FloorPlans_Grid extends rentPress_ShortCodes_Base 
{
    public function handleShortcode($atts, $content = '') 
    {
        global $wpdb;

        $attributes = shortcode_atts( array(
            'property_code' => false,
            'bed_filter_suffix' => 'Bed',
            'link_to_availability' => false,
            'display_floor_plan_name' => true,
            'available_units_only' => true,
            'display_floor_plan_image' => true,
            'order_by' => false,
            'order' => 'asc',
            'bedroom_filters' => false,
            'price_sorter' => false,
            'use_pagination' => false,
            'posts_per_page' => 10
        ), $atts );

        $wpQueryArgs = [
            'post_type' => 'floorplans',
            'post_status' => 'publish'
        ];

        if (! $attributes['use_pagination'] || $attributes['use_pagination'] == 'false' ) {
            $wpQueryArgs['nopaging'] = true;
        } else {
            $wpQueryArgs['posts_per_page'] = absint( $attributes['posts_per_page'] );
            // Protect against arbitrary 'paged' values
            $paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;
            $wpQueryArgs['paged'] = $paged;
        }

        if ( $attributes['property_code'] && $attributes['property_code'] !== 'false' ) {
            $wpQueryArgs['floorplans_of_property'] = $attributes['property_code'];
        }

        if ( $attributes['available_units_only'] && $attributes['available_units_only'] !== 'false' ) {
            $wpQueryArgs['floorplans_with_available_units'] = true;
        }

        // @ToDo this order by i dont believe works...
        if ( $attributes['order_by'] && $attributes['order'] ) {
            $wpQueryArgs['meta_key'] = $attributes['order_by'];
            $wpQueryArgs['order'] = $attributes['order'];
            if ( in_array($wpQueryArgs['orderby'], ['fpBeds', 'fpBaths', 'fpMinRent', 'fpMaxRent', 'fpMinSQFT', 'fpMaxSQFT', 'fpAvailUnitCount'])) {
                $wpQueryArgs['orderby'] = 'meta_value_num';
            }
        }

        $floorPlans = new WP_Query($wpQueryArgs);

        ob_start();

        // If no floor plans were found with the parameters given, let the user know
        if ( intval($floorPlans->found_posts) == 0 ) {
            $propertyPostID = $wpdb->get_col("
                SELECT pm.post_id FROM $wpdb->postmeta pm
                WHERE pm.meta_value = '". $attributes['property_code'] ."' AND pm.meta_key = 'prop_code'
                LIMIT 1
            ");
            $propertyName = get_post_meta($propertyPostID[0], 'propName', true);
            echo '<div id="rp-floor-plan-grid" class="none-found">';
                echo '<h3>We\'re sorry! There are no floor plans with available units for '.esc_html($propertyName).'</h3>';
            echo '</div>';
            return ob_get_clean();
        }

        if ( isset($attributes['bedroom_filters']) && (bool) $attributes['bedroom_filters'] == true ) {
            $bedroomCounts = [];
            if ( $floorPlans->have_posts() ) : while ( $floorPlans->have_posts() ) : $floorPlans->the_post();
                $bedroomCounts[] = (int) $floorPlans->post->fpBeds;
            endwhile;endif;wp_reset_postdata();
            $bedroomCounts = array_unique($bedroomCounts);
            sort($bedroomCounts, SORT_NUMERIC);
            echo '<div id="rp-floor-plan-grid-bedroom-filters" class="rp-filters" >';
                echo "<h5>Filter By Bedrooms:</h5>";
                foreach ($bedroomCounts as $bed) {
                    $text = $bed ? $bed.' '.$attributes['bed_filter_suffix'] : 'Studio';
                    echo "<a class='button btn rp-fp-filter bed-filter' data-filter='.bedroom-$bed'>$text</a>";
                }
                echo "<a class='button btn rp-fp-filter bed-filter' data-filter='all'>Reset</a>";
            echo '</div>';
        }

        if ( isset($attributes['price_sorter']) && (bool) $attributes['price_sorter'] == true ) {
            echo $this->outputPricingSorter();
        }

        if ( $floorPlans->have_posts() ) {
            global $rentPress_Service; $sorterAttributes = ''; $html = ''; $tmp = '';
            echo '<div id="rp-floor-plan-grid" class="rp-short-code fp-list">';
            // Set up pagination links if it is being used. 
            if ( (bool) $attributes['use_pagination'] ) {
                echo $this->getPagination($floorPlans);
                echo '<div style="clear:both;"></div><br/>';
            }
            while ( $floorPlans->have_posts() ) { $floorPlans->the_post();
                $floorPlanService = $rentPress_Service['floorplans_meta']->setPostID($floorPlans->post->ID); 
                $requiredClasses = " mix bedroom-{$floorPlans->post->fpBeds} ";
                $minRent = intval($floorPlans->post->fpMinRent);
                if ( isset($attributes['link_to_availability']) && (bool) $attributes['link_to_availability'] == true ) {
                    $blockLink = $floorPlans->post->fpAvailURL;
                } else {
                    $blockLink = get_the_permalink();
                }
                    $priceSorterDataAttribute = '';
                    if ( isset($attributes['price_sorter']) && (bool) $attributes['price_sorter'] == true ) :
                        $priceSorterDataAttribute .= " data-price='{$floorPlans->post->fpMinRent}' ";
                    endif;
                    $tmp = "<div class='mix rp-floorplan bedroom-{$floorPlans->post->fpBeds}'";
                    if ( $attributes['price_sorter'] && $attributes['price_sorter'] !== 'false' ) {
                        $tmp .= " data-price='{$minRent}' >";
                    } else {
                        $tmp .= ">";
                    }
                    $minRent = '$'.number_format($minRent);
                        $tmp .= "<figure>";
                            $img = $this->getFloorPlanImage($floorPlans->post->ID);
                            $tmp .= "<a href={$blockLink}>";
                                $tmp .= "<img src='{$img}' title='{$floorPlans->post->fpName}'/>";
                            $tmp .= "</a>";
                        $tmp .= "</figure>";
                        if ( $attributes['display_floor_plan_name'] && $attributes['display_floor_plan_name'] !== 'false' ) {
                            $tmp .= "<a href={$blockLink}>";
                                $tmp .= "<h4>";
                                    $tmp .= "<span>{$floorPlans->post->fpName}</span>";
                                $tmp .= "</h4>";
                            $tmp .= "</a>";
                        }
                        $tmp .= "<h5>";
                            if ( intval($floorPlans->post->fpBeds) == 0 ) {
                                $tmp .= "<span>Studio</span>";
                            } else {
                                $tmp .= "{$floorPlans->post->fpBeds} Bed</span>";
                            }
                            $tmp .= "<span>{$floorPlans->post->fpBaths}&nbsp;Bathroom</span>";
                        $tmp .= "</h5>";
                        $tmp .= "<footer class='rp-floorplan-details'>";
                            $sqft = number_format($floorPlans->post->fpMinSQFT);
                            $tmp .= "<span class='rp-dp-here'>Starting at {$minRent}</span>&nbsp;|&nbsp;";
                            $tmp .= "<span class='rp-floorplan-sqft'>{$sqft} Sq. Ft.</span>";
                            $tmp .= "<div class='rp-floorplan-units-avail'>{$floorPlans->post->fpAvailUnitCount} Apartments Available</div>";
                            if ( isset($attributes['link_to_availability']) && (bool) $attributes['link_to_availability'] == true ) :
                                $availLink = $floorPlans->post->fpAvailURL;
                                $tmp .= "<a class='button btn rp-disable-apply' href='{$availLink}'>View Availability</a>";
                            else :
                                $availLink = get_the_permalink();
                                $tmp .= "<a class='button btn rp-disable-apply' href='{$availLink}'>View Availability</a>";
                            endif;
                        $tmp .= "</footer>";
                $tmp .= "</div>";
                
                $tmp = apply_filters( 'rentPress_Floor_Plan_Grid_HTML', $tmp, $floorPlans, $requiredClasses ); 
                echo $tmp;
            } // endwhile -- End fp grid block loop

            // Set up pagination links if it is being used. 
            if ( (bool) $attributes['use_pagination'] ) {
                echo '<div style="clear:both;"></div><br/>';
                echo $this->getPagination($floorPlans);
            }
            echo '</div>';
        } else {
            echo 'No floor plans match the provided criteria. Please check your shortcode parameters.';
        }
        wp_reset_postdata();

        return ob_get_clean();
    }

    public function getFloorPlanImage($floorPlanPostID)
    {
        $fallback = 'http://placehold.it/400x350?text=Floor Plan Img';
        $optionsSettingsImageOverride = get_option('rentPress_floorplans_default_featured_image');
        if ( isset($optionsSettingsImageOverride) && strlen($optionsSettingsImageOverride) ) {
            $fallback = $optionsSettingsImageOverride;
        }
        $image = wp_get_attachment_url( get_post_thumbnail_id($floorPlanPostID) );
        if ( ! $image ) {
            $image = get_post_meta($floorPlanPostID, 'fpImg', true);
            $images = explode(',', $image); 
            if ( count($images) > 1 ) $image = $images[0]; 
        }
        // If there's a placeholder link, override with default fallback
        if ( strpos($image, 'placehold') > 0 && isset($optionsSettingsImageOverride) && strlen($optionsSettingsImageOverride)  ) {
            $image = $fallback;
        }
        return $image ? $image : $fallback;
    }

    public function getPagination($query, $args = [])
    {
        global $wp_query;

        $big = 999999999; // need an unlikely integer
        $translated = __( 'Page', 'rentPress-wp' ); // Supply translatable string
        $paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;

        return paginate_links( array_merge(array(
            'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
            'format' => '?paged=%#%',
            'current' => max( 1, $paged ),
            'total' => $query->max_num_pages,
            'before_page_number' => '<span class="screen-reader-text">'.$translated.' </span>'
        ), $args) );
    }


    public function formatPricing($cost)
    {
        $fpRentSummary = $cost === 0 ? '<i>No pricing available</i>' : 'Starting at $'.number_format($cost).'/month';
        $fpRentSummary = $cost === -1 ? 'Contact us for pricing' : $fpRentSummary;
        return $fpRentSummary;
    }

    public function outputPricingSorter($value='')
    {
        $pricingSorter = [];
        $pricingSorter[] = '<div id="rp-floor-plan-grid-price-sort" class="rp-sorter">';
            $pricingSorter[] = "<h5>Sort by Price:</h5>";
            $pricingSorter[] = "<a class='button btn rp-fp-sort price-sort' data-sort='price:asc'>Min - Max Price</a>";
            $pricingSorter[] = "<a class='button btn rp-fp-sort price-sort' data-sort='price:desc'>Max - Min Price</a>";
        $pricingSorter[] = '</div>';
        return join('', $pricingSorter);
    }
}