<?php
/**
 * The template for displaying all pages.
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package 30_Lines_Properties
 */

global $rentPress_Service;

$rentPressOptions = new rentPress_Options();

//set up variables for later use
$availability_type = $rentPressOptions->getOption('override_unit_visibility');
$today = strtotime( "+1 days", time());
$lookahead = rp_single_fp_getFutureTime($rentPressOptions);
$waitlist_url = ($rentPressOptions->getOption('show_waitlist_override_url') == '/waitlist') 
	? site_url().'/waitlist'
	: $rentPressOptions->getOption('show_waitlist_override_url') ;
$show_waitlist_ctas = ($rentPressOptions->getOption('show_waitlist_ctas') != 'false') ? true : false ;

get_header();
while ( have_posts() ) : the_post();
	$currentFloorPlan = $rentPress_Service['floorplans_meta']->setPostID($post->ID);

	$fpName = sanitize_text_field($currentFloorPlan->name());
	$bedrooms = $currentFloorPlan->beds();
	$bathrooms = $currentFloorPlan->baths();
	$sqft = $currentFloorPlan->sqftg();
	$rent = $currentFloorPlan->rent();
	$availabilityUrl = esc_url($currentFloorPlan->availabilityUrl());
	$fpMatterport=get_post_meta($post->ID, 'fpMatterport', true);

	// Floorplan's Property
	$fpProperty=get_posts([
		'post_type' => 'properties',
		'property_code' => $post->parent_property_code,
		'post_status' => ['publish', 'draft'],
	])[0];

	$thePropertiesAmenities = wp_get_post_terms( $fpProperty->ID, 'prop_amenities', []);

	$propDescription = get_post_meta($fpProperty->ID, 'propDescription', true);

	// Units

	$units = $currentFloorPlan->units();
					
	// the below logic needs refactored in the future
    foreach ($units as $key => $unit) {
    	//set up a usable timestamp
		$unit->availableDateTS = ($unit->Information->AvailableOn) ? strtotime($unit->Information->AvailableOn) : null ;

        if (is_null($unit->availableDateTS) || !rp_single_fp_isAvailable($unit, $availability_type, $today, $lookahead)) {
            unset($units[$key]);
        }

    }

	// Gathering Rent Terms Available
    $distinctTermRents=[];

    if ($rentPressOptions->getOption('disbale_all_units_lt_pricing') !== 'true') {

	    $unitsTermRents=array_filter(
	    	array_map(
	    		function($unit) {
	    			return $unit->Rent->TermRent;
	    		},
	    		$units
	    	),
	    	function($termRents) {
	    		return is_object($termRents) || is_array($termRents);
		    }
		);

		foreach ($unitsTermRents as $unitTermRents) {
			foreach ($unitTermRents as $termRent) {
				$distinctTermRents[]=$termRent->Term;
			}
		}

		$distinctTermRents=array_unique($distinctTermRents);

    }

	// Similar Floorplans
	$similarFloorPlans = get_posts([
		'post_type' => 'floorplans',
		'posts_per_page' => 3,
		'orderby' => 'rand',
		'floorplans_of_similar' => true,

		'floorplans_beds' => $bedrooms,
		'floorplans_of_property' => $post->parent_property_code
	]);

	$appointmentsPluginIsActive = false;
	$infoButtonClass = "rp-button";

	if ( function_exists('is_plugin_active')) {
		if (is_plugin_active('appointments/appointments.php')){
			$appointmentsPluginIsActive = true;
			$infoButtonClass = "rp-button-alt";

			if ($rentPressOptions->getOption('override_cta_link') !== 'true' || ($rentPressOptions->getOption('single_floorplan_schedule_a_tour_url') == '')) {
				$schedule_a_tour_url=get_site_url().'/tour';
			}
			else {
				$schedule_a_tour_url=$rentPressOptions->getOption('single_floorplan_schedule_a_tour_url');
			}

			$schedule_a_tour_url.='?fpName='. $post->fpName .'&fpBeds='.$post->fpBeds;

		}
 	}


		if ($rentPressOptions->getOption('override_request_link') !== 'true' || ($rentPressOptions->getOption('single_floorplan_request_more_info_url') == '')) {
			$requestMoreInfoUrl=get_site_url().'/contact';
		}
		else {
			$requestMoreInfoUrl=$rentPressOptions->getOption('single_floorplan_request_more_info_url');
		}

		$requestMoreInfoUrl.='?fpName='.$fpName .'&property_code='. $post->parent_property_code;


	if ($rentPressOptions->getOption('single_floorplan_content_position') == 'single_floorplan_content_top') { ?>
	<div <?php post_class('rp-default-wp-content'); ?>>
		<?php the_content(); ?>
	</div>
	<?php } 

	if ($rentPressOptions->getOption('hide_floorplan_availability_counter') == true) { ?>
		<style type="text/css">
			.rp-num-avail {
				display: none;
			}
		</style>
	<?php } ?>

	<section class="rentpress-core-container">

		<section id="post-<?php the_ID(); ?>" <?php post_class('floorplans-wrapper'); ?>>

		<header id="rp-single-fp-header-details">
			<div class="rp-row">
				<section class="rp-col-6 rp-single-fp-gallery">

					<?php
						$image = esc_url($currentFloorPlan->image());
						// We do this to check for cases where urls are comma separated, then we pull out the first one in the list.
						$images = explode(',', $image);
						if ( is_array($images) && count($images) > 1 ) $image = $images[0];
					?>

					<?php
						/*
							<section id="single-floor-plan-image" class="rp-single-fp-gallery-slide">
								<img src="<?php echo $image; ?>">
								<img src="http://placehold.it/400x400" alt="">
								<img src="http://placehold.it/500x350" alt="">
							</section>

							<div class="rp-single-fp-gallery-thumbs">
								<span>
									<img src="<?php echo $image; ?>">
								</span>
								<span>
									<img src="http://placehold.it/75x75" alt="">
								</span>
								<span>
									<img src="http://placehold.it/75x75" alt="">
								</span>
							</div>
						*/
					?>

					<figure id="rp-single-fp-image">
						<a href="<?php echo $image; ?>" data-mfp-src="<?php echo $image; ?>" id="rp-single-fp-open-image-popup">
							<img src="<?php echo $image; ?>">
						</a>
					</figure>
				</section>

				<aside class="rp-single-fp-content rp-col-6">

					<div class="rp-single-fp-sub-details">
						<?php if ($rentPressOptions->getOption('override_single_floorplan_template_title') === 'true') : ?>
							<h2>
								<?php echo $post->post_title; ?>
							</h2>
						<?php else : ?>
							<h2>
								<span><?php echo rp_single_fp_getBedBathString($bedrooms, rp_single_fp_getBathroomString($bathrooms)); ?></span>
							</h2>
						<?php endif; ?>

						<span><?php echo number_format($sqft); ?> Sq. Ft.</span> |
						<span class="rp-dp-here"><?php echo $currentFloorPlan->displayRentForTemplate(); ?></span>
					</div>

					<form id="rp-single-fp-all-the-unit-things">

						<?php if (count($units) > 0 && count($distinctTermRents) > 0) : ?>
							<div class="rp-form-legend">
								<h4>Choose a lease term</h4>
								<select name="rentTerm" id="">
									<option value="">Choose...</option>
									<?php foreach ($distinctTermRents as $termRent) : ?>
										<option value="<?php echo $termRent; ?>"><?php echo $termRent; ?> Months</option>
									<?php endforeach; ?>
								</select>
							</div>
						<?php endif; ?>

						<div class="rp-form-legend">
							<?php if (count($units) > 0) : ?>
								<h4>Choose an Apartment</h4>

								<section id="rpUnitCards" class="rp-unit-cards">
									<?php
										foreach ($units as $unit) {
											$Unit = $rentPress_Service['unit_meta']->fromUnit($unit);
											$rent=$Unit->rent();
											?>
												<div class="rp-unit-card" data-unit-code="<?php echo $unit->Identification->UnitCode; ?>" >
													<label role="button">
														<input type="radio" name="unit" class="rp-radio-unit-number" id="<?php echo $unit->Information->Name; ?>" data-unit-avail-link="<?php echo $Unit->availabilityLink(); ?>" style="display: none;">

														<h5 class="rp-card-title"><?php echo $unit->Information->Name; ?></h5>

														<p class="rp-card-rent rp-dp-here">
															$<span data-is-price
																data-defualt-rent="<?php echo $rent; ?>"
																data-rent-terms="<?php echo esc_attr(json_encode((array)$unit->Rent->TermRent)); ?>"><?php echo $rent; ?></span>/mo
														</p>

														<p class="rp-card-sqft"><?php echo $unit->SquareFeet->Max; ?> sq. ft.</p>

														<p class="rp-card-avail">
															<?php
																if ($unit->Information->isAvailable) {
																	echo "Available Now";
																}
																else {
																	echo "Available ". $unit->Information->AvailableOn;
																}
															?>
														</p>
													</label>
												</div>
											<?php
										}
									?>
								</section><!-- rp-unit-cards -->

							<?php else : ?>

								<div class='rp-single-no-units-wrapper'>
								<h4 class='rp-single-no-units-headline'>No Apartments Available</h4>
								<p class='rp-single-no-units-text'>This is one of our most popular layouts. No apartments are currently available. You can browse our <a class='rp-primary-accent' href='/floorplans/'>other options</a>.</p>
								<br>
								</div>


							<?php endif; ?>
						</div>

						<!-- If available units, show Tour, Info, and Apply buttons -->
						<?php if (count($units) == 0 && $show_waitlist_ctas) : ?>
							<footer id="rp-single-fp-form-buttons">

								<a href="<?= $waitlist_url ?>" id="rp-fp-app-link" class="rp-button rp-waitlist-button">Join Our Waitlist</a>

								<?php if ($appointmentsPluginIsActive && isset($schedule_a_tour_url) && ($rentPressOptions->getOption('tour_cta_button') == 'true')) : ?>
									<a href="<?php echo esc_url($schedule_a_tour_url); ?>" class="rp-button-alt rp-tour-button">
										Schedule A Tour
									</a>
								<?php endif; ?>

								<a href="/floorplans/" class="rp-button-alt rp-floorplans-back-button>">Browse Floorplans</a>

							</footer>
						
						<!-- If no units, show Waitlist, Tour, and floorplans buttons -->
						<?php else : ?>
							

							<footer id="rp-single-fp-form-buttons">
								<?php if ($appointmentsPluginIsActive && isset($schedule_a_tour_url) && ($rentPressOptions->getOption('tour_cta_button') == 'true')) : ?>
									<a href="<?php echo esc_url($schedule_a_tour_url); ?>" class="rp-button">
										Schedule A Tour
									</a>
								<?php endif; ?>

								<?php if (isset($requestMoreInfoUrl)) : ?>

									<a href="<?php echo esc_url($requestMoreInfoUrl); ?>" class="<?php echo $infoButtonClass; ?>">Request More Info</a>

								<?php endif; ?>

								<a href="<?php echo $availabilityUrl; ?>" target="<?php echo $rentPressOptions->getOption('override_apply_links_targets'); ?>" id="rp-fp-app-link" class="rp-button-alt button-alt more-info-button">Apply Now</a>
							</footer>


						<?php endif; ?>
					</form>

					<div id="rp-single-fp-share-section">
						<h4>Share This Floor Plan</h4>
						<nav class="rp-single-fp-share-nav">

							<a href="<?php echo esc_url('https://twitter.com/share?url='. get_permalink().'&amp;text='. $post->post_title .'&amp;hashtags=apartments'); ?>" target="_blank">
								<span class="icomoon rp-icon-twitter"></span>
							</a>

							<a href="<?php echo esc_url('http://www.facebook.com/sharer.php?u='. get_permalink()); ?>" target="_blank">
								<span class="icomoon rp-icon-facebook"></span>
							</a>

							<a href="mailto:?subject=Check Out This Apartment&body=I liked this apartment at <?php echo esc_attr($fpProperty->post_title); ?>. What do you think? <?php echo esc_attr(get_the_permalink()); ?>">
								<span class="icomoon rp-icon-envelope"></span>
							</a>
						</nav>
					</div>

					<!-- <span class="rp-is-fav rp-primary-accent"></span> -->

				</aside>

				<!-- <div class="clearfix"></div> -->

			</div>
		</header>


		<!-- Tour Section -->
		<!-- TODO:This section should support the third button for Schedule Tour but I could not get it to stack -->
		<?php if ($fpMatterport != '') : ?>
			<section>
				<h3 class="text-center rp-padded-y rp-tour-header">Take A Look Around</h3>
				<iframe class="rp-tour-frame"src="<?php echo $fpMatterport; ?>" width="100%" height="600" frameborder="0" allowfullscreen="allowfullscreen"></iframe>
						<footer id="rp-single-fp-form-buttons" style="display: flex; justify-content: center;">
							<!-- <?php if ($appointmentsPluginIsActive && isset($schedule_a_tour_url) && ($rentPressOptions->getOption('tour_cta_button') == 'true')) : ?>
								<a href="<?php echo esc_url($schedule_a_tour_url); ?>" class="rp-button" style="min-width: 12em;">
									Schedule A Tour
								</a>
								&nbsp;
							<?php endif; ?> -->

							<?php if (isset($requestMoreInfoUrl)) : ?>

								<a href="<?php echo esc_url($requestMoreInfoUrl); ?>" style="min-width: 12em;" class="<?php echo $infoButtonClass; ?>">Request More Info</a>

								&nbsp;
							<?php endif; ?>

							<a href="<?php echo $availabilityUrl; ?>" target="<?php echo $rentPressOptions->getOption('override_apply_links_targets'); ?>" id="rp-fp-app-link" style="min-width: 12em;" class="rp-button-alt button-alt more-info-button">Apply Now</a>
						</footer>
						<br>
			</section>
		<?php endif; ?>

		<section id="rp-single-fp-features" class="rp-padded-y">
			<div class="rp-row">

			<?php if( $propDescription ) : ?>

				<aside class="rp-col-6 rp-single-text">
					<p><strong>About Our Community</strong></p>
					<p class="meta-desc-text"><?php echo $propDescription; ?></p>
				</aside>

				<section class="rp-col-6 rp-single-feat-list">
					<p><strong>Features</strong></p>
					<ul>
						<?php
							foreach ($thePropertiesAmenities as $amenity) {
								echo "<li>". $amenity->name ."</li>";
							}
						?>
					</ul>
				</section>

			<?php else: ?>

				<section class="rp-col-6 is-centered rp-single-feat-list">
					<p><strong>Features</strong></p>
					<ul>
						<?php
							foreach ($thePropertiesAmenities as $amenity) {
								echo "<li>". $amenity->name ."</li>";
							}
						?>
					</ul>
				</section>

			<?php endif; ?>

			</div>
		</section>

		<section class="rp-row">

			<h3 class="text-center rp-padded-y">Similar Floorplans</h3>

			<div class="rp-single-list rp-col-12">

				<?php foreach ( $similarFloorPlans as $floorPlan ) :
					$similarFloorPlan = $rentPress_Service['floorplans_meta']->setPostID($floorPlan->ID);
					$fpName = sanitize_text_field($similarFloorPlan->name());
					$bedrooms = esc_html__($similarFloorPlan->beds(), RENTPRESS_LANG_KEY);
					$bathrooms = esc_html__($similarFloorPlan->baths(), RENTPRESS_LANG_KEY);
					$sqft = esc_html__($similarFloorPlan->sqftg(), RENTPRESS_LANG_KEY);
					$fpRent = $similarFloorPlan->rent();

					$similar_fp_units = $similarFloorPlan->units();
					
					// the below logic needs refactored in the future
					$available_units = 0;
				    $apartments = 0;

				    foreach ($similar_fp_units as $unit) {

				    	//set up a usable timestamp
	        			$unit->availableDateTS = ($unit->Information->AvailableOn) ? strtotime($unit->Information->AvailableOn) : null ;

			            if ($availability_type != 'unit_visibility_5' && $unit->Information->AvailableOn != '1970-01-01' && rp_single_fp_isAvailable($unit, $availability_type, $today, $lookahead)) {
			                $available_units++;
			            }
			            $apartments++;
				    }

				    if ($rentPressOptions->getOption('hide_floorplans_without_availability') == true && $available_units == 0) {
				    	continue;
				    } 
				?>

					<div class="rp-single-list-floorplan avail-now">
						<a href="<?php echo get_permalink($floorPlan->ID); ?>">

							<figure>
								<img src="<?php echo $similarFloorPlan->image(); ?>">
							</figure>

							<footer class="rp-fp-details">
								<?php if ($rentPressOptions->getOption('override_single_floorplan_template_title') === 'true') : ?>
									<h5>
										<?php echo $floorPlan->post_title; ?>
									</h5>
								<?php else : ?>
										<h5><span><?php echo rp_single_fp_getBedBathString($bedrooms, rp_single_fp_getBathroomString($bathrooms)); ?></span></h5>
								<?php endif; ?>

								<span><?php echo number_format($sqft); ?> Sq. Ft.</span> | <span class=""><?php echo $similarFloorPlan->displayRentForTemplate(); ?></span>

								
								<?php if ($show_waitlist_ctas && $available_units == 0 && $availability_type != 'unit_visibility_5') : ?>
									<div class="rp-num-avail rp-primary-accent">Join Waitlist</span></div>
								<?php elseif ($availability_type != 'unit_visibility_5') : ?>
									<div class="rp-num-avail rp-primary-accent"><?php echo $available_units; ?> Available</div>
								<?php else : ?>
									<div class="rp-num-avail rp-primary-accent"><?php echo $apartments; ?> Apartments</span></div>
								<?php endif; ?>
							</footer>

						</a>
						<!-- <span class="rp-is-fav rp-primary-accent"></span> -->
					</div> <!-- floorplan -->
				<?php endforeach; ?>

			</div>

		</section>

		<div id="floorplans-back-btn" style="display: flex; align-items: center; justify-content: center;">
			<a style="text-align: center;" class="rp-button-alt" href="<?php echo site_url(); ?>/floorplans">Back to Floor Plans</a>
		</div>
		<br>

		</section><!-- floorplans-wrapper -->


	</section><!-- rentpress-core-container -->

	<?php if ($rentPressOptions->getOption('single_floorplan_content_position') == 'single_floorplan_content_bottom') { ?>
		<div <?php post_class('rp-default-wp-content'); ?>>
			<?php the_content(); ?>
		</div>
	<?php } ?>

<?php get_footer();
endwhile;

function rp_single_fp_getFutureTime($rentPressOptions)
{
    $date = $rentPressOptions->getOption('use_avail_units_before_this_date');
    return strtotime( "+$date days", time());
}

function rp_single_fp_isAvailable($unit, $option, $today, $lookahead){
    $isAvailable = false;

    switch ($option) {
        // Show all with date and/or availability status
        case 'unit_visibility_1':
            $isAvailable = ($unit->Information->isAvailable || $unit->Information->AvailableOn) ? true : false ;
            break;
        // Show all with availability status
        case 'unit_visibility_2':
            $isAvailable = ($unit->Information->isAvailable) ? true : false ;
            break;
        // Show units only available today
        case 'unit_visibility_3':
            $isAvailable = ($unit->availableDateTS && $unit->availableDateTS < $today) ? true : false ;
            break;
        // Show available today and soon
        case 'unit_visibility_4':
            $isAvailable = ($unit->availableDateTS && $unit->availableDateTS < $lookahead) ? true : false ;
            break;
        case 'unit_visibility_5':
            $isAvailable = true;
            break;
    }

    return $isAvailable;
}

function rp_single_fp_getBathroomString($bathCount)
{
    return (fmod(floatval($bathCount), 1) == 0.5) ? number_format($bathCount, 1) : number_format($bathCount) ;
}

function rp_single_fp_getBedBathString($bedCount, $bathrooms)
{
    return ($bedCount == 0) ? 
            "Studio | ".$bathrooms." Bath" : 
            $bedCount." Bed | ".$bathrooms." Bath" ;
}